==> fim-0.1-alpha.tar.gz: fim-0.1-alpha/src/Command.h <==
/* $Id: Command.h 38 2007-05-01 11:14:38Z dezperado $ */
/*
 Command.h : Fim Command class header file

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef COMMAND_FBVI_H
#define COMMAND_FBVI_H
#include "fim.h"
namespace fim
{

class Command
{
	public:
	fim::string cmd,
		    help ;
	Command(fim::string cmd,fim::string help,Browser *b=NULL,fim::string(Browser::*bf)(const std::vector<fim::string>&)=NULL) :cmd(cmd),help(help),browserf(bf),browser(b) { type=BrowserT;}
	Command(fim::string cmd,fim::string help,CommandConsole *c=NULL,fim::string(CommandConsole::*cf)(const std::vector<fim::string>&)=NULL) :cmd(cmd),help(help),consolef(cf),console(c) { type=CommandConsoleT;}

	fim::string getHelp()const{return help;}
	private:
	enum	{ BrowserT,CommandConsoleT };
	int type;
	union{
		fim::string (Browser::*browserf)(const std::vector<fim::string>&) ;
		fim::string (CommandConsole::*consolef)(const std::vector<fim::string>&) ;
	};
	union{
		Browser *browser;
		CommandConsole *console;
	};

	public:
	
	~Command() { }
	
/*	fim::string execute(const std::vector<Arg> &args)
	{
//		assert(browser && browserf);
//		(browser->*browserf)(args);	
		assert(0);
//		std::cout<<"ddddaaaaaah\n";
		return "not ok.";
	}*/

	fim::string execute(const std::vector<fim::string> &args)
	{
	//	assert(browser && browserf);
		assert(browser);//!!!!!!!!!!!!!!!!!!
		//std::cerr <<  "about to execute '"<<cmd.c_str();for(int i=0;i<args.size();++i)std::cerr << " " << args[i].c_str(); std::cerr << "'\n";
		if(!browser || !browserf)
		{
			//std::cout << cmd.c_str() << " : "<< "\n";
			return "problems executing command..";
		}else
		return (browser->*browserf)(args);
	}

	bool operator < (Command c)const{return cmd< c.cmd;}
	bool operator <=(Command c)const{return cmd<=c.cmd;}
};
}
#endif

==> fim-0.3-alpha.tar.gz: fim-0.3-alpha/src/Command.h <==
/* $Id: Command.h 135 2008-05-06 20:41:10Z dezperado $ */
/*
 Command.h : Fim Command class header file

 (c) 2007 Michele Martone

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/
#ifndef COMMAND_FBVI_H
#define COMMAND_FBVI_H
#include "fim.h"
namespace fim
{

class Command
{
	public:
	fim::string cmd,
		    help ;
	Command(fim::string cmd,fim::string help,Browser *b=NULL,fim::string(Browser::*bf)(const std::vector<fim::string>&)=NULL) :cmd(cmd),help(help),browserf(bf),browser(b),type(0) { type=BrowserT;}
	Command(fim::string cmd,fim::string help,CommandConsole *c=NULL,fim::string(CommandConsole::*cf)(const std::vector<fim::string>&)=NULL) :cmd(cmd),help(help),consolef(cf),console(c),type(0) { type=CommandConsoleT;}
#ifdef FIM_WINDOWS
	Command(fim::string cmd,fim::string help,Window *w=NULL,fim::string(Window::*cf)(const std::vector<fim::string>&)=NULL) :cmd(cmd),help(help),windowf(cf),window(w),type(0) { type=WindowT;}
#endif

	fim::string getHelp()const{return help;}
	private:
	enum
	{
		BrowserT,
#ifdef FIM_WINDOWS
		WindowT,
#endif
		CommandConsoleT 
	};
	union{
		fim::string (Browser::*browserf)(const std::vector<fim::string>&) ;
		fim::string (CommandConsole::*consolef)(const std::vector<fim::string>&) ;
#ifdef FIM_WINDOWS
		fim::string (Window::*windowf)(const std::vector<fim::string>&) ;
#endif
	};
	union{
		Browser *browser;
		CommandConsole *console;
#ifdef FIM_WINDOWS
		Window *window;
#endif
	};
	int type;

	public:
	
	~Command() { }
	
/*	fim::string execute(const std::vector<Arg> &args)
	{
//		assert(browser && browserf);
//		(browser->*browserf)(args);	
		assert(0);
//		std::cout<<"ddddaaaaaah\n";
		return "not ok.";
	}*/

	fim::string execute(const std::vector<fim::string> &args)
	{
	//	assert(browser && browserf);
		assert(browser);//!!!!!!!!!!!!!!!!!!
		//std::cerr <<  "about to execute '"<<cmd.c_str();for(int i=0;i<args.size();++i)std::cerr << " " << args[i].c_str(); std::cerr << "'\n";
		if(!browser || !browserf)
		{
			//std::cout << cmd.c_str() << " : "<< "\n";
			return fim::string("problems executing command..");
		}else
		return (browser->*browserf)(args);
	}

	bool operator < (Command c)const{return cmd< c.cmd;}
	bool operator <=(Command c)const{return cmd<=c.cmd;}
};
}
#endif
